pub mod simple_diff;
pub mod show_dir_contents_history;
mod test_simple_diff_files;
mod test_cumulative_limit_nth;
pub mod history2;
mod test_cumulative_limit_count;

mod test_max_phase0;
mod test_max_phase0_with_cumu;
mod test_load_and_save;
